==> haskell-store-0.5.1.2-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: store
version: 0.5.1.2
id: store-0.5.1.2-9yqVzuCl6iOAR7VOroIrv4
key: store-0.5.1.2-9yqVzuCl6iOAR7VOroIrv4
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/store#readme
synopsis: Fast binary serialization
category: Serialization, Data
abi: 145099cec576aca2b657c3cd32e93560
exposed: True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer
hidden-modules: Data.Store.Impl
import-dirs: /usr/lib/ghc-8.6.5/site-local/store-0.5.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/store-0.5.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/store-0.5.1.2
hs-libraries: HSstore-0.5.1.2-9yqVzuCl6iOAR7VOroIrv4
depends:
    array-0.5.3.0 async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    base-orphans-0.8.1-1ipEgB2SRGR7acY6peEbpr
    base64-bytestring-1.0.0.2-2qZIU8NhrUrEe5vir8mbZ5
    bifunctors-5.5.6-5PqFMYFNQ7o5YGZyqtr38P bytestring-0.10.8.2
    containers-0.6.0.1 contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    cryptohash-0.11.9-CoTMowpthlAFX290whuknU deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1
    free-5.1.3-EMzhJudJxKi7PkL7nQxIgX ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hspec-2.7.1-1ym4rlU4DQD8tr1OT7RR0c
    hspec-smallcheck-0.5.2-4TC5Q7HWqJf6GlmJ4X8Fbd integer-gmp-1.0.2.0
    lifted-base-0.2.3.12-AptnLlCSRcTHtTYEKD9GFf
    monad-control-1.0.2.3-EQU08Q5uVAI5Qyu4idMrsU
    mono-traversable-1.0.15.0-9RSDslIanQuFhJ8p2US6JY
    network-2.8.0.0-LvSlvEKiGr81Yl4BCXERfa
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    resourcet-1.2.2-2dmcTwjPeuF8zenLvwytIP
    safe-0.3.18-LtdH37oJsulDSBmeOJDMc3
    smallcheck-1.1.5-IcJgcWLNXQN4xE4F00EnpE
    store-core-0.4.4.1-88VHVSUIahwun1lQttQeS
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW template-haskell-2.14.0.0
    text-1.2.3.1 th-lift-0.8.0.1-27iw5a8l71Jv8yDjPHfmr
    th-lift-instances-0.1.14-KASYyJM441aGLVgajki6ev
    th-orphans-0.13.9-dA6GVRFWI83WWwe8ma3Un
    th-reify-many-0.1.9-8b1iHTPwq1rI2fADvq3TMM
    th-utilities-0.2.3.1-ENoqcYGQrgh2qoOkgdQqai time-1.8.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-98MsUmwXpKo1DE5wGxzrlx
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI
haddock-interfaces: /usr/share/doc/haskell-store/html/store.haddock
haddock-html: /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-store-0.5.1.2-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: store
version: 0.5.1.2
id: store-0.5.1.2-Hy353OScIzjJqwULEShPiw
key: store-0.5.1.2-Hy353OScIzjJqwULEShPiw
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/store#readme
synopsis: Fast binary serialization
category: Serialization, Data
abi: 2119a34b5e6e3c44ef5e8c16aae2b01f
exposed: True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer
hidden-modules: Data.Store.Impl
import-dirs: /usr/lib/ghc-8.6.5/site-local/store-0.5.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/store-0.5.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/store-0.5.1.2
hs-libraries: HSstore-0.5.1.2-Hy353OScIzjJqwULEShPiw
depends:
    array-0.5.3.0 async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    base-orphans-0.8.1-1ipEgB2SRGR7acY6peEbpr
    base64-bytestring-1.0.0.2-2qZIU8NhrUrEe5vir8mbZ5
    bifunctors-5.5.6-5PqFMYFNQ7o5YGZyqtr38P bytestring-0.10.8.2
    containers-0.6.0.1 contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    cryptohash-0.11.9-CoTMowpthlAFX290whuknU deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1
    free-5.1.3-EMzhJudJxKi7PkL7nQxIgX ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hspec-2.7.1-1ym4rlU4DQD8tr1OT7RR0c
    hspec-smallcheck-0.5.2-4TC5Q7HWqJf6GlmJ4X8Fbd integer-gmp-1.0.2.0
    lifted-base-0.2.3.12-AptnLlCSRcTHtTYEKD9GFf
    monad-control-1.0.2.3-EQU08Q5uVAI5Qyu4idMrsU
    mono-traversable-1.0.15.1-AcQoEjGYMhUI3AymNmI5XD
    network-2.8.0.0-LvSlvEKiGr81Yl4BCXERfa
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    resourcet-1.2.2-2dmcTwjPeuF8zenLvwytIP
    safe-0.3.18-LtdH37oJsulDSBmeOJDMc3
    smallcheck-1.1.5-IcJgcWLNXQN4xE4F00EnpE
    store-core-0.4.4.1-88VHVSUIahwun1lQttQeS
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW template-haskell-2.14.0.0
    text-1.2.3.1 th-lift-0.8.0.1-27iw5a8l71Jv8yDjPHfmr
    th-lift-instances-0.1.14-KASYyJM441aGLVgajki6ev
    th-orphans-0.13.9-dA6GVRFWI83WWwe8ma3Un
    th-reify-many-0.1.9-8b1iHTPwq1rI2fADvq3TMM
    th-utilities-0.2.3.1-ENoqcYGQrgh2qoOkgdQqai time-1.8.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-98MsUmwXpKo1DE5wGxzrlx
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI
haddock-interfaces: /usr/share/doc/haskell-store/html/store.haddock
haddock-html: /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
